@@ -51,6 +51,7 @@
 #include "snapper/Btrfs.h"
 #include "snapper/BtrfsUtils.h"
 #include "snapper/File.h"
+#include "snapper/Hooks.h"
 #include "snapper/Snapper.h"
 #include "snapper/SnapperTmpl.h"
 #include "snapper/SnapperDefines.h"
@@ -91,7 +92,7 @@ namespace snapper
 #ifdef ENABLE_BTRFS_QUOTA
 
 	string qgroup_str;
-	if (config_info.getValue("QGROUP", qgroup_str) && !qgroup_str.empty())
+	if (config_info.get_value("QGROUP", qgroup_str) && !qgroup_str.empty())
 	{
 	    try
 	    {
@@ -1531,6 +1532,8 @@ namespace snapper
 		subvolid_t id = get_id(snapshot_dir.fd());
 		set_default_id(general_dir.fd(), id);
 	    }
+
+	    Hooks::set_default_snapshot(subvolume, this, num);
 	}
 	catch (const runtime_error& e)
 	{
