@@ -108,8 +108,8 @@ namespace snapper
 		   const string& mount_data) const;
 	bool umount(const string& mount_point) const;
 
-	bool fsetfilecon(const string& name, char* con) const;
-	bool fsetfilecon(char* con) const;
+	bool fsetfilecon(const string& name, const char* con) const;
+	bool fsetfilecon(const char* con) const;
 	bool restorecon(SelinuxLabelHandle* sh) const;
 	bool restorecon(const string& name, SelinuxLabelHandle* sh) const;
 
@@ -146,7 +146,7 @@ namespace snapper
 	ssize_t listxattr(char* list, size_t size) const;
 	ssize_t getxattr(const char* name, void* value, size_t size) const;
 
-	void fsetfilecon(char* con) const;
+	void fsetfilecon(const char* con) const;
 	void restorecon(SelinuxLabelHandle* sh) const;
 
     private:
