@@ -144,7 +144,7 @@ namespace snapper
     void
     Snapshot::setDefault() const
     {
-	return snapper->getFilesystem()->setDefault(num);
+	snapper->getFilesystem()->setDefault(num);
     }
 
 
@@ -733,7 +733,7 @@ namespace snapper
 	    SN_RETHROW(e);
 	}
 
-	Hooks::create_snapshot(snapper->subvolumeDir(), snapper->getFilesystem());
+	Hooks::create_snapshot(snapper->subvolumeDir(), snapper->getFilesystem(), snapshot);
 
 	return entries.insert(entries.end(), snapshot);
     }
@@ -753,7 +753,7 @@ namespace snapper
 
 	snapshot->writeInfo();
 
-	Hooks::modify_snapshot(snapper->subvolumeDir(), snapper->getFilesystem());
+	Hooks::modify_snapshot(snapper->subvolumeDir(), snapper->getFilesystem(), *snapshot);
     }
 
 
@@ -792,9 +792,9 @@ namespace snapper
 	SDir infos_dir = snapper->openInfosDir();
 	infos_dir.unlink(decString(snapshot->getNum()), AT_REMOVEDIR);
 
-	entries.erase(snapshot);
+	Hooks::delete_snapshot(snapper->subvolumeDir(), snapper->getFilesystem(), *snapshot);
 
-	Hooks::delete_snapshot(snapper->subvolumeDir(), snapper->getFilesystem());
+	entries.erase(snapshot);
     }
 
 
