@@ -1,5 +1,6 @@
 /*
  * Copyright (c) [2010-2012] Novell, Inc.
+ * Copyright (c) [2020-2022] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -34,7 +35,7 @@ namespace snapper
 	: doc(xmlNewDoc((const xmlChar*) "1.0"))
     {
 	if (!doc)
-	    throw BadAllocException();
+	    SN_THROW(BadAllocException());
     }
 
 
@@ -44,7 +45,7 @@ namespace snapper
 	close(fd);
 
 	if (!doc)
-	    throw IOErrorException("xmlReadFd failed");
+	    SN_THROW(IOErrorException("xmlReadFd failed"));
     }
 
 
@@ -52,13 +53,14 @@ namespace snapper
 	: doc(xmlReadFile(filename.c_str(), NULL, XML_PARSE_NOBLANKS | XML_PARSE_NONET))
     {
 	if (!doc)
-	    throw IOErrorException("xmlReadFile failed");
+	    SN_THROW(IOErrorException("xmlReadFile failed"));
     }
 
 
     XmlFile::~XmlFile()
     {
 	xmlFreeDoc(doc);
+	doc = nullptr;
     }
 
 
@@ -67,15 +69,22 @@ namespace snapper
     {
 	FILE* f = fdopen(fd, "w");
 	if (!f)
-	    throw IOErrorException("fdopen");
+	{
+	    close(fd);
+	    SN_THROW(IOErrorException("fdopen"));
+	}
 
 	if (xmlDocFormatDump(f, doc, 1) == -1)
 	{
 	    fclose(f);
-	    throw IOErrorException("xmlDocFormatDump failed");
+	    SN_THROW(IOErrorException("xmlDocFormatDump failed"));
 	}
 
-	fclose(f);
+	fflush(f);
+	fsync(fileno(f));
+
+	if (fclose(f) != 0)
+	    SN_THROW(IOErrorException("fclose failed"));
     }
 
 
@@ -83,7 +92,7 @@ namespace snapper
     XmlFile::save(const string& filename)
     {
 	if (xmlSaveFormatFile(filename.c_str(), doc, 1) == -1)
-	    throw IOErrorException("xmlSaveFormatFile failed");
+	    SN_THROW(IOErrorException("xmlSaveFormatFile failed"));
     }
 
 
@@ -106,6 +115,7 @@ namespace snapper
     {
 	if (node != NULL)
 	    node = node->children;
+
 	for (const xmlNode* cur_node = node; cur_node; cur_node = cur_node->next)
 	{
 	    if (strcmp(name, (const char*) cur_node->name) == 0)
@@ -125,6 +135,7 @@ namespace snapper
 
 	if (node != NULL)
 	    node = node->children;
+
 	for (const xmlNode* cur_node = node; cur_node; cur_node = cur_node->next)
 	{
 	    if (cur_node->type == XML_ELEMENT_NODE &&
@@ -137,6 +148,7 @@ namespace snapper
 	return ret;
     }
 
+
     bool
     getValue(const xmlNode* node, string& value)
     {
@@ -144,16 +156,18 @@ namespace snapper
 	if (tmp == nullptr)
 	    return false;
 
-	value = (const char *) tmp;
+	value = (const char*) tmp;
 	xmlFree(tmp);
 	return true;
     }
 
+
     bool
     getChildValue(const xmlNode* node, const char* name, string& value)
     {
 	if (node != NULL)
 	    node = node->children;
+
 	for (const xmlNode* cur_node = node; cur_node; cur_node = cur_node->next)
 	{
 	    if (cur_node->type == XML_ELEMENT_NODE &&
@@ -183,18 +197,20 @@ namespace snapper
 	return true;
     }
 
+
     bool
     getAttributeValue(const xmlNode* node, const char* name, string& value)
     {
-	xmlChar* tmp = xmlGetNoNsProp(node, (const xmlChar *) name);
+	xmlChar* tmp = xmlGetNoNsProp(node, (const xmlChar*) name);
 	if (tmp == nullptr)
 	    return false;
 
-	value = (const char *) tmp;
+	value = (const char*) tmp;
 	xmlFree(tmp);
 	return true;
     }
 
+
     bool
     getAttributeValue(const xmlNode* node, const char* name, bool& value)
     {
@@ -206,6 +222,7 @@ namespace snapper
 	return true;
     }
 
+
     void
     setChildValue(xmlNode* node, const char* name, const char* value)
     {
